package com.waimai.web.admin.service;

import java.util.List;
import com.waimai.web.admin.domain.FoodCategory;

/**
 * 食品分类Service接口
 * 
 * @author callmeyan
 * @date 2023-03-24
 */
public interface IFoodCategoryService 
{
    /**
     * 查询食品分类
     * 
     * @param id 食品分类主键
     * @return 食品分类
     */
    public FoodCategory selectFoodCategoryById(Long id);

    /**
     * 查询食品分类列表
     * 
     * @param foodCategory 食品分类
     * @return 食品分类集合
     */
    public List<FoodCategory> selectFoodCategoryList(FoodCategory foodCategory);

    /**
     * 新增食品分类
     * 
     * @param foodCategory 食品分类
     * @return 结果
     */
    public int insertFoodCategory(FoodCategory foodCategory);

    /**
     * 修改食品分类
     * 
     * @param foodCategory 食品分类
     * @return 结果
     */
    public int updateFoodCategory(FoodCategory foodCategory);

    /**
     * 批量删除食品分类
     * 
     * @param ids 需要删除的食品分类主键集合
     * @return 结果
     */
    public int deleteFoodCategoryByIds(Long[] ids);

    /**
     * 删除食品分类信息
     * 
     * @param id 食品分类主键
     * @return 结果
     */
    public int deleteFoodCategoryById(Long id);
}
